@@ -56,8 +56,6 @@ GRL_LOG_DOMAIN(flickr_log_domain);
 
 /* --- Plugin information --- */
 
-#define PLUGIN_ID   FLICKR_PLUGIN_ID
-
 #define PUBLIC_SOURCE_ID   "grl-flickr"
 #define PUBLIC_SOURCE_NAME "Flickr"
 #define PUBLIC_SOURCE_DESC _("A source for browsing and searching Flickr photos")
@@ -248,9 +246,18 @@ grl_flickr_plugin_init (GrlRegistry *registry,
   return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_flickr_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_DEFINE (GRL_MAJOR,
+                   GRL_MINOR,
+                   FLICKR_PLUGIN_ID,
+                   "Flickr",
+                   "A plugin for browsing and searching Flickr photos",
+                   "Igalia S.L.",
+                   VERSION,
+                   "LGPL",
+                   "http://www.igalia.com",
+                   grl_flickr_plugin_init,
+                   NULL,
+                   NULL);
 
 /* ================== Flickr GObject ================ */
 
@@ -272,7 +279,7 @@ grl_flickr_source_public_new (const gchar *flickr_api_key,
                          "source-id", PUBLIC_SOURCE_ID,
                          "source-name", PUBLIC_SOURCE_NAME,
                          "source-desc", PUBLIC_SOURCE_DESC,
-                         "supported-media", GRL_MEDIA_TYPE_IMAGE,
+                         "supported-media", GRL_SUPPORTED_MEDIA_IMAGE,
                          "source-tags", tags,
                          NULL);
   source->priv->flickr = g_flickr_new (flickr_api_key, flickr_secret,
@@ -632,7 +639,7 @@ photosetslist_cb (GFlickr *f, GList *photosets, gpointer user_data)
 
   while (photosets && count > 0) {
     count--;
-    media = grl_media_box_new ();
+    media = grl_media_container_new ();
     grl_media_set_id (media,
                       g_hash_table_lookup (photosets->data,
                                            "photoset_id"));
@@ -734,7 +741,7 @@ gettags_cb (GFlickr *f, GList *taglist, gpointer user_data)
   count = g_list_length (taglist);
   while (taglist) {
     count--;
-    media = grl_media_box_new ();
+    media = grl_media_container_new ();
     grl_media_set_id (media, taglist->data);
     grl_media_set_title (media, taglist->data);
     bs->callback (bs->source,
