@@ -81,6 +81,7 @@ test_resolve_metrolyrics (void)
    { "back it up", "caro emerald", LYRICS_BACK_IT_UP },
    { "bohemian rhapsody", "queen", LYRICS_BOHEMIAN_RHAPSODY },
    { "nobodys perfect", "jessie j", LYRICS_NOBODYS_PERFECT },
+   { "100% pure love", "crystal waters", NULL },
   };
 
   source = test_lua_factory_get_source (METROLYRICS_ID, METROLYRICS_OPS);
@@ -91,13 +92,19 @@ test_resolve_metrolyrics (void)
     gsize size;
     GError *error = NULL;
 
+    lyrics = get_lyrics (source, audios[i].artist, audios[i].title);
+    if (audios[i].lyrics_file == NULL) {
+        /* We are not interested in comparing this lyrics */
+        g_clear_pointer (&lyrics, g_free);
+        continue;
+    }
+    g_assert_nonnull (lyrics);
+
     file = g_file_new_for_uri (audios[i].lyrics_file);
     g_file_load_contents (file, NULL, &data, &size, NULL, &error);
     g_assert_no_error (error);
     g_clear_pointer (&file, g_object_unref);
 
-    lyrics = get_lyrics (source, audios[i].artist, audios[i].title);
-    g_assert_nonnull (lyrics);
     if (g_ascii_strncasecmp (lyrics, data, size - 1) != 0) {
       g_warning ("Lyrics of '%s' from '%s' changed. Check if metrolyrics.com changed",
                   audios[i].title, audios[i].artist);
@@ -107,6 +114,31 @@ test_resolve_metrolyrics (void)
   }
 }
 
+static void
+test_resolve_metrolyrics_bad_request (void)
+{
+  GrlSource *source;
+  guint i;
+
+  struct {
+    gchar *title;
+    gchar *artist;
+    gchar *lyrics_file;
+  } audios[] = {
+   { "GNOME", "grilo framework", NULL },
+  };
+
+  source = test_lua_factory_get_source (METROLYRICS_ID, METROLYRICS_OPS);
+
+  for (i = 0; i < G_N_ELEMENTS (audios); i++) {
+    gchar *lyrics;
+
+    g_test_expect_message("Grilo", G_LOG_LEVEL_WARNING, "*Can't fetch element*");
+    lyrics = get_lyrics (source, audios[i].artist, audios[i].title);
+    g_assert_null (lyrics);
+  }
+}
+
 gint
 main (gint argc, gchar **argv)
 {
@@ -114,6 +146,7 @@ main (gint argc, gchar **argv)
   test_lua_factory_setup (NULL);
 
   g_test_add_func ("/lua_factory/sources/metrolyrics", test_resolve_metrolyrics);
+  g_test_add_func ("/lua_factory/sources/metrolyrics/bad-request", test_resolve_metrolyrics_bad_request);
 
   gint result = g_test_run ();
 
